@@ -12,7 +12,7 @@ import (
 	"k8s.io/kube-state-metrics/pkg/metric"
 
 	"github.com/golang/glog"
-	"github.com/openshift/api/quota/v1"
+	v1 "github.com/openshift/api/quota/v1"
 	quotaclient "github.com/openshift/client-go/quota/clientset/versioned"
 	"k8s.io/kube-state-metrics/pkg/version"
 )
